@@ -17,9 +17,7 @@
 
 #include <QAction>
 #include <QDebug>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkInformation>
-#endif
 #include <QScreen>
 #include <QSortFilterProxyModel>
 #include <QTimer>
@@ -38,9 +36,6 @@
 #include <Plasma/Containment>
 
 #include "comicmodel.h"
-#include "comicupdater.h"
-
-Q_GLOBAL_STATIC(ComicUpdater, globalComicUpdater)
 
 ComicApplet::ComicApplet(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Applet(parent, data, args)
@@ -62,12 +57,10 @@ ComicApplet::ComicApplet(QObject *parent, const KPluginMetaData &data, const QVa
     , mSavingDir(nullptr)
 {
     setHasConfigurationInterface(true);
-    connect(mEngine, &ComicEngine::requestFinished, this, &ComicApplet::dataUpdated);
 }
 
 void ComicApplet::init()
 {
-    globalComicUpdater->init(globalConfig());
     mSavingDir = new SavingDir(config());
 
     configChanged();
@@ -86,7 +79,7 @@ void ComicApplet::init()
 
     mActionNextNewStripTab = new QAction(QIcon::fromTheme(QStringLiteral("go-next-view")), i18nc("@action comic strip", "&Next Tab with a New Strip"), this);
     mActionNextNewStripTab->setShortcuts(KStandardShortcut::openNew());
-    actions()->addAction(QStringLiteral("next new strip"), mActionNextNewStripTab);
+    setInternalAction(QStringLiteral("next new strip"), mActionNextNewStripTab);
     mActions.append(mActionNextNewStripTab);
     connect(mActionNextNewStripTab, &QAction::triggered, this, &ComicApplet::showNextNewStrip);
 
@@ -144,19 +137,7 @@ void ComicApplet::init()
     updateUsedComics();
     changeComic(true);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_DEPRECATED
-    connect(&m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged, this, [this](bool isOnline) {
-        if (!isOnline) {
-            return;
-        }
-        qCDebug(PLASMA_COMIC) << "Online status changed to true, requesting comic" << mPreviousFailedIdentifier;
-        mEngine->requestSource(mPreviousFailedIdentifier);
-    });
-    QT_WARNING_POP
-#else
-    QNetworkInformation::instance()->load(QNetworkInformation::Feature::Reachability);
+    QNetworkInformation::instance()->loadBackendByFeatures(QNetworkInformation::Feature::Reachability);
     connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, [this](auto reachability) {
         if (reachability != QNetworkInformation::Reachability::Online) {
             return;
@@ -164,7 +145,6 @@ void ComicApplet::init()
         qCDebug(PLASMA_COMIC) << "Online status changed to true, requesting comic" << mPreviousFailedIdentifier;
         mEngine->requestSource(mPreviousFailedIdentifier);
     });
-#endif
 }
 
 ComicApplet::~ComicApplet()
@@ -347,8 +327,6 @@ void ComicApplet::configChanged()
     if (oldMaxComicLimit != mMaxComicLimit) {
         mEngine->setMaxComicLimit(mMaxComicLimit);
     }
-
-    globalComicUpdater->load();
 }
 
 void ComicApplet::saveConfig()
@@ -365,8 +343,6 @@ void ComicApplet::saveConfig()
     cg.writeEntry("tabIdentifier", mTabIdentifier);
     cg.writeEntry("checkNewComicStripsIntervall", mCheckNewComicStripsInterval);
     cg.writeEntry("maxComicLimit", mMaxComicLimit);
-
-    globalComicUpdater->save();
 }
 
 void ComicApplet::slotNextDay()
@@ -708,21 +684,6 @@ void ComicApplet::setCheckNewComicStripsInterval(int interval)
     Q_EMIT checkNewComicStripsIntervalChanged();
 }
 
-int ComicApplet::providerUpdateInterval() const
-{
-    return globalComicUpdater->interval();
-}
-
-void ComicApplet::setProviderUpdateInterval(int interval)
-{
-    if (globalComicUpdater->interval() == interval) {
-        return;
-    }
-
-    globalComicUpdater->setInterval(interval);
-    Q_EMIT providerUpdateIntervalChanged();
-}
-
 void ComicApplet::setMaxComicLimit(int limit)
 {
     if (mMaxComicLimit == limit) {
