@@ -12,24 +12,25 @@
 #include <QDebug>
 #include <QDesktopServices>
 #include <QGuiApplication>
-#include <QMutex>
+#include <QLocale>
+#include <QMimeData>
 
+#include <chrono>
 #include <cmath>
 
-static QMutex s_initMutex;
+using namespace std::chrono_literals;
 
 K_PLUGIN_CLASS_WITH_JSON(ConverterRunner, "plasma-runner-converter.json")
 
-ConverterRunner::ConverterRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : AbstractRunner(parent, metaData, args)
-{
-    setObjectName(QStringLiteral("Converter"));
+Q_DECLARE_METATYPE(KUnitConversion::Value)
 
-    const QString description = i18n(
-        "Converts the value of :q: when :q: is made up of "
-        "\"value unit [>, to, as, in] unit\". You can use the "
-        "Unit converter applet to find all available units.");
-    addSyntax(RunnerSyntax(QStringLiteral(":q:"), description));
+ConverterRunner::ConverterRunner(QObject *parent, const KPluginMetaData &metaData)
+    : AbstractRunner(parent, metaData)
+    , actionList({Action(QStringLiteral("copy"), i18n("Copy unit and number"), QStringLiteral("edit-copy"))})
+{
+    addSyntax(QStringLiteral(":q:"),
+              i18n("Converts the value of :q: when :q: is made up of value unit [>, to, as, in] unit."
+                   "You can use the Unit converter applet to find all available units."));
 }
 
 void ConverterRunner::init()
@@ -43,9 +44,15 @@ void ConverterRunner::init()
     conversionRegex.append(QStringLiteral(" ?> ?"));
     unitSeperatorRegex = QRegularExpression(conversionRegex);
 
-    actionList = {new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy unit and number"), this)};
     setMinLetterCount(2);
     setMatchRegex(valueRegex);
+
+    converter = std::make_unique<KUnitConversion::Converter>();
+    updateCompatibleUnits();
+
+    m_currencyUpdateTimer.setInterval(24h);
+    connect(&m_currencyUpdateTimer, &QTimer::timeout, this, &ConverterRunner::updateCompatibleUnits);
+    m_currencyUpdateTimer.start();
 }
 
 ConverterRunner::~ConverterRunner() = default;
@@ -65,15 +72,6 @@ void ConverterRunner::match(RunnerContext &context)
         return;
     }
 
-    // Initialize if not done already
-    {
-        QMutexLocker lock(&s_initMutex);
-        if (!converter) {
-            converter = std::make_unique<KUnitConversion::Converter>();
-            insertCompatibleUnits();
-        }
-    }
-
     // Check if unit is valid, otherwise check for the value in the compatibleUnits map
     QString inputUnitString = unitStrings.first().simplified();
     KUnitConversion::UnitCategory inputCategory = converter->categoryForUnit(inputUnitString);
@@ -107,14 +105,14 @@ void ConverterRunner::match(RunnerContext &context)
         }
 
         QueryMatch match(this);
-        match.setType(QueryMatch::HelperMatch);
+        match.setCategoryRelevance(QueryMatch::CategoryRelevance::Moderate);
         match.setIconName(QStringLiteral("accessories-calculator"));
         if (outputUnit.categoryId() == KUnitConversion::CurrencyCategory) {
             match.setText(QStringLiteral("%1 (%2)").arg(outputValue.toString(0, 'f', 2), outputUnit.symbol()));
         } else {
             match.setText(QStringLiteral("%1 (%2)").arg(outputValue.toString(), outputUnit.symbol()));
         }
-        match.setData(outputValue.number());
+        match.setData(QVariant::fromValue(outputValue));
         match.setRelevance(1.0 - std::abs(std::log10(outputValue.number())) / 50.0);
         match.setActions(actionList);
         matches.append(match);
@@ -123,22 +121,27 @@ void ConverterRunner::match(RunnerContext &context)
     context.addMatches(matches);
 }
 
-void ConverterRunner::run(const RunnerContext &context, const QueryMatch &match)
+void ConverterRunner::run(const RunnerContext & /*context*/, const QueryMatch &match)
 {
-    Q_UNUSED(context)
+    const auto value = match.data().value<KUnitConversion::Value>();
 
     if (match.selectedAction()) {
-        const QString text = match.text();
-        QGuiApplication::clipboard()->setText(text.left(text.indexOf(QLatin1String(" ("))));
+        QGuiApplication::clipboard()->setText(value.toString());
     } else {
-        QGuiApplication::clipboard()->setText(match.data().toString());
+        QGuiApplication::clipboard()->setText(QString::number(value.number(), 'f', QLocale::FloatingPointShortest));
     }
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-QPair<bool, double> ConverterRunner::stringToDouble(const QStringRef &value)
-#else
+
+QMimeData *ConverterRunner::mimeDataForMatch(const QueryMatch &match)
+{
+    const auto value = match.data().value<KUnitConversion::Value>();
+
+    auto *mimeData = new QMimeData();
+    mimeData->setText(value.toSymbolString());
+    return mimeData;
+}
+
 QPair<bool, double> ConverterRunner::stringToDouble(const QStringView &value)
-#endif
 {
     bool ok;
     double numberValue = locale.toDouble(value, &ok);
@@ -150,11 +153,7 @@ QPair<bool, double> ConverterRunner::stringToDouble(const QStringView &value)
 
 QPair<bool, double> ConverterRunner::getValidatedNumberValue(const QString &value)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const auto fractionParts = value.splitRef(QLatin1Char('/'), Qt::SkipEmptyParts);
-#else
     const auto fractionParts = QStringView(value).split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#endif
     if (fractionParts.isEmpty() || fractionParts.count() > 2) {
         return {false, 0};
     }
@@ -215,11 +214,20 @@ QList<KUnitConversion::Unit> ConverterRunner::createResultUnits(QString &outputU
     return units;
 }
 
-void ConverterRunner::insertCompatibleUnits()
+void ConverterRunner::updateCompatibleUnits()
 {
     // Add all currency symbols to the map, if their ISO code is supported by backend
+    KUnitConversion::UnitCategory currencyCategory = converter->category(KUnitConversion::CurrencyCategory);
+    if (auto updateJob = currencyCategory.syncConversionTable(); updateJob) {
+        QEventLoop waitForFinshed;
+        waitForFinshed.connect(updateJob, &KUnitConversion::UpdateJob::finished, &waitForFinshed, &QEventLoop::quit);
+        waitForFinshed.exec();
+        compatibleUnits.clear();
+    } else if (!compatibleUnits.empty()) {
+        return; // Already filled and is not expired
+    }
+
     const QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
-    KUnitConversion::UnitCategory currencyCategory = converter->category(QStringLiteral("Currency"));
     const QStringList availableISOCodes = currencyCategory.allUnits();
     const QRegularExpression hasCurrencyRegex = QRegularExpression(QStringLiteral("\\p{Sc}")); // clazy:exclude=use-static-qregularexpression
     for (const auto &currencyLocale : allLocales) {
