@@ -9,13 +9,14 @@
 #define CONVERTERRUNNER_H
 
 #include <KRunner/AbstractRunner>
+#include <KRunner/Action>
 #include <KUnitConversion/Converter>
 #include <KUnitConversion/UnitCategory>
-#include <QAction>
 #include <QLocale>
 #include <QRegularExpression>
+#include <QTimer>
 
-using namespace Plasma;
+using namespace KRunner;
 
 /**
  * This class converts values to different units.
@@ -25,15 +26,17 @@ class ConverterRunner : public AbstractRunner
     Q_OBJECT
 
 public:
-    ConverterRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    ConverterRunner(QObject *parent, const KPluginMetaData &metaData);
     void init() override;
-    void insertCompatibleUnits();
     ~ConverterRunner() override;
 
     void match(RunnerContext &context) override;
     void run(const RunnerContext &context, const QueryMatch &match) override;
     QMimeData *mimeDataForMatch(const QueryMatch &match) override;
 
+private Q_SLOTS:
+    void updateCompatibleUnits();
+
 private:
     std::unique_ptr<KUnitConversion::Converter> converter;
     const QLocale locale;
@@ -42,12 +45,10 @@ private:
     /** To convert currency symbols back to ISO string and handle case sensitive units */
     QMap<QString, QString> compatibleUnits;
 
-    QList<QAction *> actionList;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QPair<bool, double> stringToDouble(const QStringRef &value);
-#else
+    QTimer m_currencyUpdateTimer;
+
+    const KRunner::Actions actionList;
     QPair<bool, double> stringToDouble(const QStringView &value);
-#endif
     QPair<bool, double> getValidatedNumberValue(const QString &value);
     QList<KUnitConversion::Unit> createResultUnits(QString &outputUnitString, const KUnitConversion::UnitCategory &category);
 };
