@@ -11,14 +11,14 @@
 #include "profilesmodel.h"
 #include <KRunner/AbstractRunner>
 
-using namespace Plasma;
+using namespace KRunner;
 
 class KonsoleProfiles : public AbstractRunner
 {
     Q_OBJECT
 
 public:
-    explicit KonsoleProfiles(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    explicit KonsoleProfiles(QObject *parent, const KPluginMetaData &metaData);
 
     void init() override;
     void match(RunnerContext &context) override;
