@@ -27,7 +27,17 @@ class FlickrProvider : public PotdProvider
 public:
     explicit FlickrProvider(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
+Q_SIGNALS:
+    void configLoaded(const QString &apiKey, const QString &apiSecret);
+
+private Q_SLOTS:
+    void configRequestFinished(KJob *job);
+    void configWriteFinished(KJob *job);
+
 private:
+    void loadConfig();
+    void refreshConfig();
+
     void sendXmlRequest(const QString &apiKey);
     void xmlRequestFinished(KJob *job);
     void imageRequestFinished(KJob *job);
@@ -38,8 +48,14 @@ private:
     void pageRequestFinished(KJob *job);
 
 private:
+    QString m_configLocalPath;
+    QUrl m_configRemoteUrl;
+    QUrl m_configLocalUrl;
     QDate mActualDate;
     QString mApiKey;
+    bool m_refreshed = false;
+
+    QImage m_image;
 
     QXmlStreamReader xml;
 
